# FediCheck OSS - ActivityPub Denylist Service

FediCheck OSS is an open-source web service that allows ActivityPub service providers to review and subscribe to external sources for automated domain block updates. It includes three modules:

1. An observatory that monitors upstream servers and/or CSV files of domain block recommendations
2. An app that can group the recommendations by agreement and automatedly push additions, edits, and retractions
3. An API to server the resulting lists as a JSON payload

This project is based on FediCheck, originally developed by IFTAS.

## Features

- Connect to and manage denylists from one or more sources
- OAuth integration with Mastodon servers
- Configurable update schedule for denylist synchronization
- Options to customize blocking policies (suspend vs. silence)
- Comprehensive safety features to protect your instance
- Admin dashboard for API key management and configuration

## How It Works

Signing in and requesting permissions is handled via passthrough of OAuth to your Mastodon server, similar to how third-party clients like Elk work.

The synchronization process can be enabled or disabled at any time through a simple interface.

Updates are pushed to opted-in servers on a configurable basis to address changes to the lists, new additions, or retractions that may occur.

## Admin Dashboard & API Keys

FediCheck OSS includes an admin dashboard that allows administrators to manage API keys for programmatic access to the service. This enables integration with other tools and automated workflows.

For more detailed information about API key management and the available API endpoints, please refer to the [API dasboard repo for documentatons](https://github.com/iftas-org/FedicheckOSS-API-Dashboard.git).

## Safety Features

- App credentials are encrypted with a unique key generated for every app and stored in the .env file before being stored in the database
- CSRF protection and a Content Security Policy
- Option to downgrade suspends to silences when your server has people following the targeted domain (requires the `admin:read` permission)
- Clear "Enable" and "Disable" controls with opt-out by default
- Protection for existing federation entries on your server
- Domain blocks created by this application are identified in the Private Comment field
- One-click option to remove all managed domain blocks
- Ability to purge all data about your server and revoke credentials at any time

## Setup and Running

### Using Docker (Recommended for development)

1. Run `make setup` to generate the `.env` file and initial configuration.
2. Modify the `.env` file to set:
   - `DATABASE_URL=postgres://example:password@db:5432/fedicheck`
   - `REDIS_URL=redis://redis:6379`
3. Run `make data` to start the Redis and PostgreSQL services in Docker.
4. Run `make migrate` to set up the database schema.
5. In one terminal, run `make start` to start the web server.
6. In another terminal, run `make worker` to start the background worker.

The app will be accessible at http://localhost:8080

### Non-Docker Setup (For production or full control)

1. Run `make setup` or `node app/setup.js` to generate the `.env` file.
2. Modify the `.env` file to point to your Postgres and Redis databases:
   - Set `DATABASE_URL` to your PostgreSQL connection string
   - Set `REDIS_URL` to your Redis connection string
   - **Sentry DSN**: If you plan to use Sentry for error tracking, update the `SENTRY_DSN` with your Sentry project's DSN.
3. Navigate to the `./app` folder and run `npm install` (or `npm install --omit-dev` for production).
4. Run `make migrate` to set up the database schema.
5. Run `make start` to start the server.
6. In another terminal, run `make worker` to start the worker process.

The app will be accessible at http://localhost:8080

### Additional Commands

- `make generatekey`: Generate a new secret key for the application.

Note: The `--watch-path=app/` flag in the `start` and `worker` commands enables auto-reloading for development. Remove this flag for production deployments.

## Contributing

Contributions to FediCheck OSS are welcome! Please feel free to submit pull requests or open issues to improve the project.

## License

[//TOO:]

## Acknowledgments

This project is based on the original CARIAD FediCheck developed by IFTAS. This OSS version aims to provide an open-source alternative for ActivityPub communities.
