import env from "../src/env.js";

import { db } from "../src/db.js";
import * as Schema from "../src/db/schema.js";
import { getUnknownDomain } from "../src/queries.js";
import { getDomainDigest } from "../src/util.js";
import { eq } from "drizzle-orm";

const domains = [
  // add domains here
];

(async () => {
  for (let domain of domains) {
    try {
      const digest = getDomainDigest(domain);
      await getUnknownDomain(digest);

      const results = await db.transaction(async (tx) => {
        await tx
          .delete(Schema.unknown_domains)
          .where(eq(Schema.unknown_domains.digest, digest));

        return await tx
          .insert(Schema.domains)
          .values({
            domain,
            digest: getDomainDigest(domain),
          })
          .onConflictDoNothing()
          .returning({ id: Schema.domains.id, domain: Schema.domains.domain });
      });

      console.log(`Processed domain: ${domain}`, results);
    } catch (err) {
      console.error(`Error processing domain ${domain}:`, err);
    }
  }
})();
