import pino from "pino";
import path from "path";
import { fileURLToPath } from "url";
import { migrate } from "drizzle-orm/node-postgres/migrator";
import { db, dbPool } from "../src/db.js";
import * as Schema from "../src/db/schema.js";

import dataMigrations from "../src/db/migrations/index.js";

const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);

const logger = pino({ name: "migrator" });

logger.info("Running migrations...");

// this will automatically run needed migrations on the database
await migrate(db, { migrationsFolder: path.join(__dirname, "../migrations") });

logger.info("Running data migrations...");

// Run data migrations:
for (let migration of dataMigrations) {
  await migration.run(db, Schema, logger);
}

logger.info("Migrations complete.");

await dbPool.end();

process.exit(0);