import pino from "pino";

import { getActualServerPushLimit } from "../src/fetcher.js";
import { pushBlocklist } from "../src/blocklist.js";
import { getServerConfigBy } from "../src/queries.js";

// set up logging
const logger = pino({});

async function main(argv) {
  const serverId = argv[0];

  if (isNaN(parseInt(serverId, 10))) {
    throw new Error("Expected serverId argument to be an integer");
  }

  const server = await getServerConfigBy("id", serverId);

  if (!server.enabled) {
    throw new Error("push to this server is not currently enabled");
  }

  logger.info(`Pushing for server: ${server.server}`);

  const push_limit = await getActualServerPushLimit(server.server);
  logger.info({ server, push_limit }, `Push limits for ${server.server}`);

  if (push_limit > 0) {
    await pushBlocklist(server.server, push_limit, logger);
  } else {
    logger.error("Not enough pushes available");
  }
}

main(process.argv.slice(2))
  .then(() => {
    process.exit(0);
  })
  .catch((err) => {
    console.error(err);
    process.exit(1);
  });
