import Graceful from "@ladjs/graceful";
import pino from "pino";

import env from "../src/env.js";
import { dbPool } from "../src/db.js";
import { redis } from "../src/redis.js";
import app from "../src/app.js";

const logger = pino({});

const server = app.listen(env.PORT, env.BIND, () => {
  logger.info(`FediCheck is up! Access at ${env.PUBLIC_URL}`);
});

// handle graceful reloads, pm2 support, and events like auth sessions, jobs locks.
const graceful = new Graceful({
  servers: [server],
  redisClients: [redis],
  customHandlers: [
    async () => {
      try {
        await dbPool.end();
      } catch (err) {
        logger.error(err);
      }
    },
  ],
  logger,
});
graceful.listen();
