import * as constants from "../src/constants.js";
import { fileURLToPath } from "url";
import path from "path";

import Bree from "bree";
import Graceful from "@ladjs/graceful";
import pino from "pino";

const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);

// set up logging
const logger = pino({ name: "scheduler" });

// set up jobs/scheduler
// configuration in src/jobs folder
const bree = new Bree({
  logger,
  root: path.join(__dirname, "../src/jobs"),
  jobs: [
    {
      name: "initialize", // only fires on start
    },
    {
      name: "push_blocks",
      interval: `every ${constants.RUNNER_SCHEDULE_IN_MINUTES} minutes`,
      closeWorkerAfterMs: 1000 * 60 * constants.RUNNER_SCHEDULE_IN_MINUTES, // close this worker before the next begins
    },
    {
      name: "update_lists",
      interval: `every ${constants.LATENCY} minutes`,
    },
    {
      name: "purge_domain_audit",
      interval: "24hrs",
    },
    {
      name: "monitor_domain_changes",
      interval: "every 24 hours",
      timeout: "20m", // Add explicit timeout
    },
  ],
  errorHandler: (error) => {
    logger.error(
      { error: error.toString(), stack: error.stack },
      "Bree encountered an error handling a job",
    );
  },
});

// handle graceful reloads, pm2 support, and events like SIGHUP, SIGINT, etc.
const graceful = new Graceful({
  brees: [bree],
  logger,
});
graceful.listen();

await bree.start();

logger.info(
  `Runner scheduled every ${constants.RUNNER_SCHEDULE_IN_MINUTES} minutes.`,
);
