DO $$ BEGIN
 CREATE TYPE "public"."block_file_format" AS ENUM('mastodon', 'fediblockhole');
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 CREATE TYPE "public"."blocklist_option" AS ENUM('add', 'edit', 'delete');
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 CREATE TYPE "public"."blocklist_types" AS ENUM('minimum', 'moderate', 'maximum');
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 CREATE TYPE "public"."follow_status" AS ENUM('unchecked', 'pending', 'updating_followers', 'ready');
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "accounts" (
	"id" uuid PRIMARY KEY DEFAULT gen_random_uuid() NOT NULL,
	"server_id" integer NOT NULL,
	"account_id" numeric NOT NULL,
	"username" text NOT NULL,
	"display_name" text,
	"access_token" text,
	"created_date" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
	"last_login_date" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
	"last_token_verify_date" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "admin_sessions" (
	"id" text PRIMARY KEY NOT NULL,
	"admin_id" integer NOT NULL,
	"token" text NOT NULL,
	"created_at" timestamp DEFAULT now(),
	"expires_at" timestamp NOT NULL
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "api_key_permissions" (
	"id" serial PRIMARY KEY NOT NULL,
	"api_key_id" integer NOT NULL,
	"permission" varchar(50) NOT NULL,
	"created_at" timestamp DEFAULT now()
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "api_keys" (
	"id" serial PRIMARY KEY NOT NULL,
	"key" text NOT NULL,
	"description" text,
	"created_at" timestamp DEFAULT now(),
	"last_used_at" timestamp,
	"is_active" boolean DEFAULT true,
	"is_admin" boolean DEFAULT false,
	CONSTRAINT "api_keys_key_unique" UNIQUE("key")
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "api_request_logs" (
	"id" serial PRIMARY KEY NOT NULL,
	"api_key_id" integer,
	"endpoint" text NOT NULL,
	"method" text NOT NULL,
	"timestamp" timestamp DEFAULT now(),
	"ip_address" text,
	"user_agent" text
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "api_threshold_requests" (
	"id" serial PRIMARY KEY NOT NULL,
	"api_key_id" integer NOT NULL,
	"threshold" varchar(10) NOT NULL,
	"request_count" integer DEFAULT 0 NOT NULL,
	"last_used" timestamp DEFAULT now(),
	"created_at" timestamp DEFAULT now()
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "blocks" (
	"server_id" integer NOT NULL,
	"domain_id" integer NOT NULL,
	"block_ref" varchar,
	"severity" varchar NOT NULL,
	"is_managed" boolean DEFAULT false NOT NULL,
	"is_admin" boolean DEFAULT false NOT NULL,
	"safelist" boolean DEFAULT false NOT NULL,
	"public_comment" text,
	"private_comment" text,
	"reject_media" boolean DEFAULT false NOT NULL,
	"created_date" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
	"last_updated_date" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
	"removed" boolean DEFAULT false NOT NULL,
	"removed_date" timestamp,
	"updated" boolean DEFAULT true NOT NULL,
	"blocklist_option" "blocklist_option",
	CONSTRAINT "blocks_server_id_domain_id_pk" PRIMARY KEY("server_id","domain_id")
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "domain_audit_history" (
	"id" serial PRIMARY KEY NOT NULL,
	"domain_id" integer NOT NULL,
	"old_percent" double precision NOT NULL,
	"new_percent" double precision NOT NULL,
	"old_severity" varchar,
	"new_severity" varchar,
	"change_reason" varchar,
	"created_at" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "domain_audits" (
	"domain_id" integer PRIMARY KEY NOT NULL,
	"count" integer DEFAULT 0 NOT NULL,
	"percent" double precision DEFAULT 0 NOT NULL,
	"public_comment" text,
	"severity" varchar NOT NULL,
	"count_suspend" integer DEFAULT 0 NOT NULL,
	"count_silence" integer DEFAULT 0 NOT NULL,
	"count_noop" integer DEFAULT 0 NOT NULL,
	"authoritative" boolean DEFAULT false NOT NULL,
	"created_date" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
	"updated_at" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "domain_audits_changelog" (
	"id" serial PRIMARY KEY NOT NULL,
	"domain_id" integer NOT NULL,
	"domainname" varchar(255) NOT NULL,
	"threshold_crossed" varchar(50) NOT NULL,
	"previous_percent" double precision NOT NULL,
	"new_percent" double precision NOT NULL,
	"datetime" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
	"authoritative" boolean DEFAULT false NOT NULL
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "domains" (
	"id" serial PRIMARY KEY NOT NULL,
	"domain" text NOT NULL,
	"digest" text NOT NULL,
	"created_date" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
	"active" boolean DEFAULT true NOT NULL,
	"approved_at" timestamp,
	CONSTRAINT "domains_domain_unique" UNIQUE("domain"),
	CONSTRAINT "domains_digest_unique" UNIQUE("digest")
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "error_logs" (
	"id" serial PRIMARY KEY NOT NULL,
	"message" text NOT NULL,
	"severity" varchar(50) NOT NULL,
	"context" jsonb,
	"user_id" bigint,
	"timestamp" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "server_config" (
	"server_id" integer PRIMARY KEY NOT NULL,
	"client_id" varchar(256) NOT NULL,
	"client_secret" varchar(256) NOT NULL,
	"api_account_id" numeric,
	"enabled" boolean DEFAULT false NOT NULL,
	"list_type" "blocklist_types" DEFAULT 'minimum' NOT NULL
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "servers" (
	"id" serial PRIMARY KEY NOT NULL,
	"server" varchar(400) NOT NULL,
	"url" text NOT NULL,
	"created_date" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
	"source" boolean DEFAULT false NOT NULL,
	"verified" boolean DEFAULT false NOT NULL,
	"is_file" boolean DEFAULT false NOT NULL,
	"authoritative" boolean DEFAULT false NOT NULL,
	"last_update_date" timestamp,
	"last_server_refresh_date" timestamp,
	"block_wipe_in_progress" boolean DEFAULT false NOT NULL,
	CONSTRAINT "servers_server_unique" UNIQUE("server"),
	CONSTRAINT "servers_url_unique" UNIQUE("url")
);
--> statement-breakpoint
CREATE TABLE IF NOT EXISTS "unknown_domains" (
	"id" uuid PRIMARY KEY DEFAULT gen_random_uuid() NOT NULL,
	"digest" text NOT NULL,
	"domain" text NOT NULL,
	"created_date" timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
	CONSTRAINT "unknown_domains_digest_unique" UNIQUE("digest"),
	CONSTRAINT "unknown_domains_domain_unique" UNIQUE("domain")
);
--> statement-breakpoint
DO $$ BEGIN
 ALTER TABLE "accounts" ADD CONSTRAINT "accounts_server_id_servers_id_fk" FOREIGN KEY ("server_id") REFERENCES "public"."servers"("id") ON DELETE cascade ON UPDATE no action;
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 ALTER TABLE "api_key_permissions" ADD CONSTRAINT "api_key_permissions_api_key_id_api_keys_id_fk" FOREIGN KEY ("api_key_id") REFERENCES "public"."api_keys"("id") ON DELETE no action ON UPDATE no action;
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 ALTER TABLE "api_request_logs" ADD CONSTRAINT "api_request_logs_api_key_id_api_keys_id_fk" FOREIGN KEY ("api_key_id") REFERENCES "public"."api_keys"("id") ON DELETE no action ON UPDATE no action;
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 ALTER TABLE "api_threshold_requests" ADD CONSTRAINT "api_threshold_requests_api_key_id_api_keys_id_fk" FOREIGN KEY ("api_key_id") REFERENCES "public"."api_keys"("id") ON DELETE no action ON UPDATE no action;
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 ALTER TABLE "blocks" ADD CONSTRAINT "blocks_server_id_servers_id_fk" FOREIGN KEY ("server_id") REFERENCES "public"."servers"("id") ON DELETE cascade ON UPDATE no action;
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 ALTER TABLE "blocks" ADD CONSTRAINT "blocks_domain_id_domains_id_fk" FOREIGN KEY ("domain_id") REFERENCES "public"."domains"("id") ON DELETE no action ON UPDATE no action;
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 ALTER TABLE "domain_audit_history" ADD CONSTRAINT "domain_audit_history_domain_id_domains_id_fk" FOREIGN KEY ("domain_id") REFERENCES "public"."domains"("id") ON DELETE no action ON UPDATE no action;
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 ALTER TABLE "domain_audits" ADD CONSTRAINT "domain_audits_domain_id_domains_id_fk" FOREIGN KEY ("domain_id") REFERENCES "public"."domains"("id") ON DELETE no action ON UPDATE no action;
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 ALTER TABLE "domain_audits_changelog" ADD CONSTRAINT "domain_audits_changelog_domain_id_domain_audits_domain_id_fk" FOREIGN KEY ("domain_id") REFERENCES "public"."domain_audits"("domain_id") ON DELETE no action ON UPDATE no action;
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
DO $$ BEGIN
 ALTER TABLE "server_config" ADD CONSTRAINT "server_config_server_id_servers_id_fk" FOREIGN KEY ("server_id") REFERENCES "public"."servers"("id") ON DELETE cascade ON UPDATE no action;
EXCEPTION
 WHEN duplicate_object THEN null;
END $$;
--> statement-breakpoint
CREATE UNIQUE INDEX IF NOT EXISTS "accounts_remote_account_idx" ON "accounts" ("server_id","account_id");--> statement-breakpoint
CREATE UNIQUE INDEX IF NOT EXISTS "idx_single_active_admin_key" ON "api_keys" ("(CASE WHEN "api_keys"."is_admin" = true AND "api_keys"."is_active" = true THEN true END)");--> statement-breakpoint
CREATE UNIQUE INDEX IF NOT EXISTS "blockref_idx" ON "blocks" ("block_ref","server_id");--> statement-breakpoint
CREATE UNIQUE INDEX IF NOT EXISTS "domain_idx" ON "domains" ("domain");--> statement-breakpoint
CREATE UNIQUE INDEX IF NOT EXISTS "digest_idx" ON "domains" ("digest");--> statement-breakpoint
CREATE UNIQUE INDEX IF NOT EXISTS "server" ON "servers" ("server");--> statement-breakpoint
CREATE UNIQUE INDEX IF NOT EXISTS "server_url" ON "servers" ("url");--> statement-breakpoint
CREATE UNIQUE INDEX IF NOT EXISTS "unknown_domain_idx" ON "unknown_domains" ("domain");