import { db } from "../src/db.js";
import { api_keys } from "../src/db/schema.js";
import { randomBytes } from 'crypto';
import { and, eq, sql } from 'drizzle-orm';

async function setupAdminApiKey() {
  try {
    // First, deactivate all existing admin keys
    await db
      .update(api_keys)
      .set({ 
        is_active: false,
        description: sql`${api_keys.description} || ' (expired at ' || NOW() || ')'`
      })
      .where(
        and(
          eq(api_keys.is_admin, true),
          eq(api_keys.is_active, true)
        )
      );

    // Generate a secure admin API key
    const adminKey = randomBytes(32).toString('hex');
    
    // Insert the new admin API key
    await db.insert(api_keys).values({
      key: adminKey,
      description: 'Admin Master Key',
      is_active: true,
      is_admin: true,
      created_at: new Date()
    });

    console.log('Previous admin keys have been deactivated');
    console.log('New Admin API Key:', adminKey);
    console.log('Store this key securely - it will not be shown again');
    console.log('Previous admin keys will no longer work');

    // Exit successfully
    process.exit(0);
  } catch (error) {
    console.error('Error setting up admin API key:', error);
    process.exit(1);
  }
}

// Run the setup
setupAdminApiKey().catch(error => {
  console.error('Failed to setup admin key:', error);
  process.exit(1);
}); 