import fs from "fs";
import crypto from "crypto";
import { exit } from "process";

const env_base_file = "./app/.env.example";
let data;
try {
  // if we're not running this from the home directory it will blow up
  // we're assuming this is being called via 'make setup' or from the root
  // directory with: node app/setup.js
  data = fs.readFileSync(env_base_file, "utf8");

  // encryption key used for securing all
  const encryption_key = crypto.randomBytes(32).toString("hex");

  // Sentry DSN placeholder
  const sentry_dsn = "https://your-sentry-dsn@o4506933008334848.ingest.us.sentry.io/4506934095708160";

  data =
    data +
    `
################## !!! DANGEROUS SECTION !!! ##################

# ENCRYPTION KEY: DO NOT CHANGE THIS UNLESS YOU KNOW WHAT YOU'RE DOING!
# This encryption secret was generated JUST FOR YOU and is used by crypto to secure
# keys and access_tokens stored in the database. If you change this value in production,
# it will immediately break all logins and integrations with existing servers.
# Run "make generatekey" in case you DO want to do this intentionally
# and replace the value here. This value was autogenerated after running
# "make setup" and cannot be overwritten. There are many encryption secrets
# but this one is yours, and yours alone. Keep it secret, keep it safe.

ENCRYPTION_SECRET=${encryption_key}

# Sentry DSN: Add your Sentry DSN here to enable error tracking
SENTRY_DSN=${sentry_dsn}
    `;
} catch (err) {
  console.error(err);
  exit(1);
}

// create an env file if it doesn't exist
const env_file = "./app/.env";
fs.access(env_file, fs.F_OK, (err) => {
  if (err) {
    console.log(".env file does not exist. Creating...");
    fs.writeFile(env_file, data, (err) => {
      if (err) {
        console.error(err);
      }
      // file written successfully
      console.log(
        "Setup completed successfully. You should edit your .env file for the needs of your application.",
      );
    });
    return;
  }

  //file exists
  console.log(".env file already exists.");
});

const toml_base_file = "./app/config.toml.example";
let toml;
try {
  toml = fs.readFileSync(toml_base_file, "utf8");
} catch (err) {
  console.error(err);
  exit(1);
}

// create config.toml if it doesn't exist
const toml_file = "./app/config.toml";
fs.access(toml_file, fs.F_OK, (err) => {
  if (err) {
    console.log("config.toml file does not exist. Creating...");
    fs.writeFile(toml_file, toml, (err) => {
      if (err) {
        console.error(err);
      }
      // file written successfully
      console.log(
        "You should edit the app/config.toml file for the needs of your application.",
      );
    });
    return;
  }

  //file exists
  console.log("config.toml file already exists.");
});
