import config from "./config.js";
import { readPackageUp } from "read-package-up";
import { fileURLToPath } from "url";
import path from "path";

const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);

const PACKAGE_JSON = await readPackageUp({ cwd: __dirname }).then(
  (result) => result?.packageJson,
);
export const VERSION = PACKAGE_JSON?.version || "1.0.0";

// these settings come from the toml file
const settings = config.get("settings");
const app = config.get("app");
const sources = config.get("sources");
const file_sources = config.get("file_sources");
const restrictions = config.get("restrictions");

export const DOMAIN_LIMIT = 200; // this is a hard API limit, we can't request more than 200 blocked domains per request
export const RATE_LIMIT_TIME_SPAN = 1000 * 60 * 5; // 5 minutes converted to milliseconds
export const RATE_LIMIT = 300;

// in minutes, how often we should be refreshing new data from source servers
export const LATENCY = settings.block_refresh_latency;
export const TOKEN_VERIFY_LATENCY = settings.token_verify_latency;

export const ADMIN_ACCOUNTS = app.admin_accounts;

export const CLIENT_NAME = "IFTAS FediCheck";
export const ENABLE_PUBLIC_COMMENTS = settings.enable_public_comments;

export const RUNNER_SCHEDULE_IN_MINUTES = settings.runner_schedule_in_minutes;

export const SERVER_PUSH_LIMIT = settings.server_push_limit;
export const SERVER_PUSH_FUZZ = settings.server_push_fuzz;

export const SHOW_SOURCES = settings.show_sources;

export const REFRESH_SOURCES_ON_STARTUP = settings.refresh_sources_on_startup;

export const MIN_TIER_PERCENT = settings.min_tier_percent;
export const MOD_TIER_PERCENT = settings.mod_tier_percent;
export const MAX_TIER_PERCENT = settings.max_tier_percent;

export const SOURCE_DOMAINS = sources.source_domains;
export const SAFE_DOMAINS = sources.safe_domains;
export const AUTHORITATIVE_DOMAINS = sources.authoritative_domains;

// create an array of allowed servers that can log in
// takes precedence over denied servers
export const ALLOWED_SERVERS = restrictions.allowed_servers;

// servers that are explicitly disallowed. Only used if allowed_servers is empty
export const DENIED_SERVERS = restrictions.denied_servers;

// source files we can use for comparison or to seed our data
export const SOURCE_FILES = {
  DNI: {
    name: "DNI",
    format: "mastodon_csv",
    url: "https://connect.iftas.org/wp-content/uploads/2024/04/dni.csv",
  },
  FediNuke: {
    name: "FediNuke List",
    format: "domain_only_csv",
    url: "https://seirdy.one/pb/FediNuke.txt",
  },
  Seirdy: {
    name: "Seirdy Tier 0",
    format: "fediblockhole",
    url: "https://seirdy.one/pb/tier0.csv",
  },
  Gardenfence: {
    name: "Gardenfence",
    format: "mastodon_csv",
    url: "https://raw.githubusercontent.com/gardenfence/blocklist/main/gardenfence-mastodon.csv",
  },
  Oliphant: {
    name: "Oliphant Unified Tier 0",
    format: "mastodon_csv",
    url: "https://codeberg.org/oliphant/blocklists/raw/branch/main/blocklists/mastodon/_unified_tier0_blocklist.csv",
  },
};

export const INCLUDED_FILE_SOURCES = file_sources.source_files;
export const AUTHORITATIVE_FILE_SOURCES = file_sources.authoritative_files;

export const IGNORED_DOMAINS = [
  "000delete.this.line.if.you.have.read.the.documentation.on.seirdy.one",
  "canary.fedinuke.example.com",
  "canary.tier0.example.com",
  "canary.tier1.example.com",
  "example.com",
];
