import pino from "pino";
import pg from "pg";
import { drizzle } from "drizzle-orm/node-postgres";
import env from "./env.js";
import * as Schema from "./db/schema.js";

const logger = pino({
  name: "database:pg",
});

/**
 * @returns {import("pg").PoolConfig}
 */
export function getOptions() {
  let options = {
    connectionString: env.DATABASE_URL,
  };

  if (env.DATABASE_CA_CERTIFICATE) {
    options.ssl = {
      rejectUnauthorized: false,
      ca: env.DATABASE_CA_CERTIFICATE,
    };
  }

  return options;
}

export const pool = new pg.Pool(getOptions());

pool.on("error", (err) => {
  logger.error(
    { error: err.toString(), stack: err.stack },
    `Error with database pool`,
  );
});

export const dbPool = pool;

// utilize a single db connection
export const db = drizzle(pool, {
  schema: Schema,
  logger: env.isDevelopment,
});
