import { and, eq, isNull } from "drizzle-orm";
import * as constants from "../../constants.js";

/**
 * @type {import("./index.js").MigrationRunner}
 */
// FIXME: this is never used, need to fix, also not indempotent if used
export async function run(db, Schema, logger) {
  // Migration to add server.url for fediverse servers:
  await db.transaction(async (tx) => {
    const servers_without_url = await tx
      .select({
        id: Schema.servers.id,
        server: Schema.servers.server,
      })
      .from(Schema.servers)
      .where(and(isNull(Schema.servers.url), eq(Schema.servers.is_file, false)))
      .for("update");

    if (servers_without_url.length <= 0) {
      return;
    }

    for (let server of servers_without_url) {
      await db
        .update(Schema.servers)
        .set({ url: `https://${server.server}/` })
        .where(eq(Schema.servers.id, server.id));
    }
  });

  // Migrate file sources to have a URL:
  await db.transaction(async (tx) => {
    const file_sources_without_url = await tx
      .select({
        id: Schema.servers.id,
        server: Schema.servers.server,
      })
      .from(Schema.servers)
      .where(
        and(
          isNull(Schema.servers.url),
          eq(Schema.servers.is_file, true),
          eq(Schema.servers.source, true),
        ),
      )
      .for("update");

    for (let fileSource of file_sources_without_url) {
      const file = constants.SOURCE_FILES[fileSource.server];

      if (!file || !file.url) {
        logger.info(`File source not found ${fileSource.server}`);
        continue;
      }

      await db
        .update(Schema.servers)
        .set({ url: file.url })
        .where(eq(Schema.servers.id, fileSource.id));
    }
  });
}
