import "dotenv/config";
import { cleanEnv, str, url, host, port, makeValidator } from "envalid";

const strWithLength = ({ minLength, ...options }) =>
  makeValidator((input) => {
    if (input.length >= minLength) {
      return input;
    } else {
      throw new TypeError(`Expected at least ${minLength} characters`);
    }
  })(options);

const env = cleanEnv(process.env, {
  NODE_ENV: str({ choices: ["development", "test", "production"] }),
  BIND: host({ default: "127.0.0.1" }),
  PORT: port({ default: 8080 }),
  PUBLIC_URL: url({ devDefault: "http://127.0.0.1:8080" }),
  DEV_PASSWORD: str({ default: "" }),
  SECRET_KEY_BASE: strWithLength({ minLength: 128 }),

  DATABASE_URL: url(),
  DATABASE_CA_CERTIFICATE: str({ devDefault: "" }),

  REDIS_URL: url(),

  SENTRY_DSN: str(),
});

export default env;
