import { BaseJob } from "../base_job.js";
import { updateSourceBlocklists } from "../blocklist.js";
import { REFRESH_SOURCES_ON_STARTUP } from "../constants.js";
import {
  initializeTrustedSources,
  preloadServerFileSources,
} from "../queries.js";

class InitializeJob extends BaseJob {
  async handle() {
    // Lock for 3 minutes:
    await this.acquireLock(60 * 1000 * 3);
    if (!this.hasLock) {
      this.logger.info("Not running due another worker having the lock.");
      return;
    }

    // on restart set all trusted sources to false and rely on the values
    // assigned in the .env to reset them to true
    this.logger.info("Initializing trusted sources...");
    await initializeTrustedSources();

    if (!this.isRunning) return;

    // any subscribed file blocklists for this service
    await preloadServerFileSources();
    if (!this.isRunning) return;

    await updateSourceBlocklists(REFRESH_SOURCES_ON_STARTUP, this.logger);

    this.logger.info("Initialization complete.");
  }
}

new InitializeJob().run();
