import { verifyAdminSecret } from '../queries.js';

export async function adminApiAuth(req, res, next) {
  const adminSecret = req.headers['x-admin-secret'] || req.query.admin_secret;
  
  if (!adminSecret) {
    return res.status(401).json({
      success: false,
      error: 'Admin secret is required'
    });
  }

  try {
    const isValid = await verifyAdminSecret(adminSecret);
    
    if (!isValid) {
      return res.status(401).json({
        success: false,
        error: 'Invalid admin secret'
      });
    }

    next();
  } catch (error) {
    console.error('Admin authentication error:', error);
    res.status(500).json({
      success: false,
      error: 'Internal server error'
    });
  }
} 