export async function adminAuthMiddleware(req, res, next) {
  // For API requests
  if (req.path.startsWith('/api/')) {
    // Get admin session token from header or query
    const adminToken = req.headers['x-admin-token'] || req.query.admin_token;
    
    // Get admin session ID
    const adminSessionId = req.headers['x-admin-session'] || req.query.admin_session;

    if (!adminToken || !adminSessionId) {
      return res.status(401).json({
        success: false,
        error: 'Admin authentication required'
      });
    }

    // Verify admin session is valid and active
    const isValidSession = await verifyAdminSession(adminSessionId, adminToken);
    if (!isValidSession) {
      return res.status(401).json({
        success: false,
        error: 'Invalid admin session'
      });
    }

    return next();
  }

  // For web requests - use existing check
  if (!res.locals.is_admin) {
    return res.redirect("/");
  }

  next();
} 