import moment from "moment";
import nunjucks from "nunjucks";
import punycode from "punycode/punycode.js";
import env from "./env.js";

export class ViewEngine {
  constructor(viewsPath) {
    this.viewsPath = viewsPath;
    this.env = new nunjucks.Environment(
      new nunjucks.FileSystemLoader(viewsPath),
      {
        autoescape: true,
      },
    );

    this.env.addFilter("dateFormat", (date, format, utc = true) => {
      return utc === true
        ? moment(date).utc().format(format)
        : moment(date).format(format);
    });

    this.env.addFilter("toUnicode", (domain) => {
      return punycode.toUnicode(domain);
    });

    if (env.isDevelopment) {
      this.env.on("load", (name, source, _loader) => {
        console.log("LOAD VIEW: %s", name, source.path);
      });
    }

    this.engine = this.renderView.bind(this);
  }

  renderView(filePath, options, callback) {
    if (env.isDevelopment) {
      console.log("renderView", options);
    }
    this.env.render(filePath, options, callback);
  }

  install(app) {
    app.engine("nj", this.engine);
    app.set("views", this.viewsPath);
    app.set("view engine", "nj");
  }
}
